@@ -1764,7 +1764,7 @@ struct UserDefined {
   bool opt_no_body;      /* as set with CURLOPT_NOBODY */
   bool upload;           /* upload request */
   enum CURL_NETRC_OPTION
-       use_netrc;        /* defined in include/curl.h */
+       use_netrc;        /* defined in include/gnurl.h */
   bool verbose;          /* output verbosity */
   bool krb;              /* Kerberos connection requested */
   bool reuse_forbid;     /* forbidden to be reused, close after use */
